<?php
/*
 *  S/MIME 0.6
 *  this release Wouter Teepe <wouter@teepe.com> and Antonio Vasconcelos
 *  (c) 2003 (GNU GPL - see ../../COPYING)
 *
 */

/* Initialize the s/mime plugin */
function squirrelmail_plugin_init_smime() 
{
   global $squirrelmail_plugin_hooks;
   $squirrelmail_plugin_hooks['read_body_header']['smime'] = "smime_header_verify_";
}


if (!defined('SM_PATH'))
   define('SM_PATH', '../');


function smime_version() 
{
  return '0.6';
}


function smime_header_verify_() 
{
   include_once(SM_PATH . 'plugins/smime/functions.php');
   smime_header_verify();
}


?>
